@@ -41,7 +41,7 @@ bool AddressBar::handleKey(const XKeyEvent &key) {
             if (addressBarCommand && addressBarCommand[0]) {
                 args[i++] = addressBarCommand;
             } else {
-#warning calling /bin/sh is considered to be bloat
+/// TODO #warning calling /bin/sh is considered to be bloat
                 args[i++] = "/bin/sh";
                 args[i++] = "-c";
             }
