@@ -157,12 +157,6 @@ char* __XOS2RedirRoot(char const*);
 #define ISMASK(w,e,n) (((w) & ~(n)) == (e))
 #define HASMASK(w,e,n) ((((w) & ~(n)) & (e)) == (e))
 
-#if 0
-//#define ISLOWER(c) ((c) >= 'a' && (c) <= 'z')
-//#define TOUPPER(c) (ISLOWER(c) ? (c) - 'a' + 'A' : (c))
-//#define TOLOWER(c) (ISLOWER(c) ? (c) : (c + 'a' - 'A'))
-#endif
-
 inline bool strIsEmpty(char const *str) {
     if (str) while (*str) if (*str++ > ' ') return false;
     return true;
@@ -177,20 +171,6 @@ const char *my_basename(const char *filename);
 bool strequal(const char *a, const char *b);
 int strnullcmp(const char *a, const char *b);
 
-#if 0
-inline char *strlower(char *str) {
-    for (char *c = str; *c; ++c) *c = TOLOWER(*c);
-    return str;
-}
-#endif
-
-#if 0
-inline char *strupper(char *str) {
-    for (char *c = str; *c; ++c) *c = TOUPPER(*c);
-    return str;
-}
-#endif
-
 template <class T>
 inline char const * niceUnit(T & val, char const * const units[],
                              T const lim = 10240, T const div = 1024) {
