@@ -36,10 +36,14 @@ public:
     bool checkMessageEvent(const XClientMessageEvent &message);
     void requestDock();
 
-    void handleUnmap(const XUnmapEvent &) {
-        MSG(("hide"));
-        if (visible())
+    void handleUnmap(const XUnmapEvent &ev) {
+        YWindow::handleUnmap(ev);
+        MSG(("hide1"));
+//        if (visible() && ev.window == handle()) {
+            MSG(("hide2"));
             hide();
+            fManaged = false;
+//        }
     }
 
     void trayChanged();
@@ -47,6 +51,7 @@ private:
     Atom icewm_internal_tray;
     Atom _NET_SYSTEM_TRAY_OPCODE;
     YXTray *fTray2;
+    bool fManaged;
 };
 
 class SysTrayApp: public YXApplication {
@@ -183,6 +188,7 @@ SysTray::SysTray(): YWindow(0) {
     setSize(fTray2->width(),
             fTray2->height());
     fTray2->show();
+    fManaged = false;
     requestDock();
 }
     
@@ -190,6 +196,15 @@ void SysTray::trayChanged() {
     fTray2->backgroundChanged();
     setSize(fTray2->width(),
             fTray2->height());
+    if (fTray2->visible()) {
+        if (!fManaged)
+            requestDock();
+        else
+            show();
+    } else {
+        fManaged = false;
+        hide();
+    }
 }
 
 void SysTray::requestDock() {
@@ -209,19 +224,25 @@ void SysTray::requestDock() {
 
         XSendEvent(xapp->display(), w, False, StructureNotifyMask, (XEvent *) &xev);
     }
+    fManaged = true;
 }
 
 bool SysTray::checkMessageEvent(const XClientMessageEvent &message) {
     if (message.message_type == icewm_internal_tray) {
-        MSG(("requestDock"));
-        requestDock();
+        MSG(("requestDock %lX", (long)handle()));
+        setSize(fTray2->width(),
+                fTray2->height());
+        MSG(("requestDock2 %d %d", width(), height()));
+        if (fTray2->visible())
+            requestDock();
+        else
+            fManaged = false;
     }
     return true;
 }
 
 int main(int argc, char **argv) {
     YLocale locale;
-
     SysTrayApp stapp(&argc, &argv);
 
     return app->mainLoop();
