@@ -9,29 +9,31 @@ class Program;
 class ObjectButton: public YButton {
 public:
     ObjectButton(YWindow *parent, DObject *object): 
- 	YButton(parent, 0), fObject(object) {}
+        YButton(parent, 0), fObject(object) {}
     ObjectButton(YWindow *parent, YMenu *popup):
-	YButton(parent, 0, popup), fObject(NULL) {}
+        YButton(parent, 0, popup), fObject(NULL) {}
+    ObjectButton(YWindow *parent, YAction *action):
+        YButton(parent, action, 0), fObject(NULL) { /* hack */ }
 
     virtual ~ObjectButton() {}
 
     virtual void actionPerformed(YAction *action, unsigned int modifiers);
-    virtual YFont * getFont();
+    virtual ref<YFont> getFont();
     virtual YColor * getColor();
     virtual YSurface getSurface();
 
 private:
     DObject *fObject;
 
-    static YFont *font;
+    static ref<YFont> font;
     static YColor *bgColor;
     static YColor *fgColor;
 };
 
-extern YPixmap *toolbuttonPixmap;
+extern ref<YPixmap> toolbuttonPixmap;
 
 #ifdef CONFIG_GRADIENTS
-extern class YPixbuf *toolbuttonPixbuf;
+extern ref<YPixbuf> toolbuttonPixbuf;
 #endif
 
 #endif
