@@ -477,7 +477,9 @@ static void initPixmaps() {
 
                     loadGradient(paths, gradient, logoutPixbuf, "logoutbg.xpm") &&
                     loadGradient(paths, gradient, switchbackPixbuf, "switchbg.xpm") &&
+#ifndef LITE
                     loadGradient(paths, gradient, listbackPixbuf, "listbg.xpm") &&
+#endif
                     loadGradient(paths, gradient, dialogbackPixbuf, "dialogbg.xpm") &&
 
                     loadGradient(paths, gradient, menubackPixbuf, "menubg.xpm") &&
@@ -576,7 +578,6 @@ static void initPixmaps() {
         titleL[0] = paths.loadPixmap(0, "titleIL.xpm");
         titleP[0] = paths.loadPixmap(0, "titleIP.xpm");
         titleM[0] = paths.loadPixmap(0, "titleIM.xpm");
-        titleB[0] = paths.loadPixmap(0, "titleIB.xpm");
         titleR[0] = paths.loadPixmap(0, "titleIR.xpm");
         titleQ[0] = paths.loadPixmap(0, "titleIQ.xpm");
         titleJ[1] = paths.loadPixmap(0, "titleAJ.xpm");
@@ -753,7 +754,7 @@ static void initMenus() {
                 logoutMenu->add(new DObjectMenuItem(restartIcewm));
 
             DProgram *restartXTerm =
-                DProgram::newProgram(_("Restart _Xterm"), 0, true, 0, "xterm", noargs);
+                DProgram::newProgram(_("Restart _Xterm"), 0, true, 0, "x-terminal-emulator", noargs);
             if (restartXTerm)
                 logoutMenu->add(new DObjectMenuItem(restartXTerm));
 #endif
@@ -1172,7 +1173,7 @@ YWMApp::YWMApp(int *argc, char ***argv, const char *displayName):
         focusOnAppRaise = false;
         requestFocusOnAppRaise = true;
         raiseOnFocus = false;
-        raiseOnClickClient = false;
+        raiseOnClickClient = true;
         focusOnMap = true;
         mapInactiveOnTop = true;
         focusChangesWorkspace = false;
@@ -1185,8 +1186,8 @@ YWMApp::YWMApp(int *argc, char ***argv, const char *displayName):
     DEPRECATE(warpPointer == true);
     DEPRECATE(focusRootWindow == true);
     DEPRECATE(replayMenuCancelClick == true);
-    DEPRECATE(manualPlacement == true);
-    DEPRECATE(strongPointerFocus == true);
+    //DEPRECATE(manualPlacement == true);
+    //DEPRECATE(strongPointerFocus == true);
     DEPRECATE(showPopupsAbovePointer == true);
     DEPRECATE(considerHorizBorder == true);
     DEPRECATE(considerVertBorder == true);
