@@ -40,10 +40,11 @@ void YClientContainer::handleButton(const XButtonEvent &button) {
         (!useMouseWheel || (button.button != 4 && button.button != 5)))
     {
         if (focusOnClickClient) {
-            if (getFrame()->canFocus() && !getFrame()->focused())
-                firstClick = true;
-            if (!getFrame()->isTypeDock())
+            if (!getFrame()->isTypeDock()) {
                 doActivate = true;
+                if (getFrame()->canFocusByMouse() && !getFrame()->focused())
+                    firstClick = true;
+            }
         }
         if (raiseOnClickClient) {
             doRaise = true;
@@ -94,6 +95,10 @@ void YClientContainer::handleButton(const XButtonEvent &button) {
                                       0, 0,
                                       px, py);
             return ;
+        } else if (IS_WMKEY(k, vm, gMouseWinRaise)) {
+            XAllowEvents(xapp->display(), AsyncPointer, CurrentTime);
+            getFrame()->wmRaise();
+            return ;
         }
     }
 #endif
@@ -158,6 +163,8 @@ void YClientContainer::grabActions() {
                 grabVButton(gMouseWinMove.key - XK_Pointer_Button1 + 1, gMouseWinMove.mod);
             if (gMouseWinSize.key != 0)
                 grabVButton(gMouseWinSize.key - XK_Pointer_Button1 + 1, gMouseWinSize.mod);
+            if (gMouseWinRaise.key != 0)
+                grabVButton(gMouseWinRaise.key - XK_Pointer_Button1 + 1, gMouseWinRaise.mod);
         }
     }
 }
