@@ -673,6 +673,12 @@ void YWindowManager::handleClientMessage(const XClientMessageEvent &message) {
             rebootOrShutdown = 1;
             wmapp->doLogout();
             break;
+        case ICEWM_ACTION_WINDOWLIST:
+            wmapp->actionPerformed(actionWindowList, 0);
+            break;
+        case ICEWM_ACTION_ABOUT:
+            wmapp->actionPerformed(actionAbout, 0);
+            break;
         }
     }
 }
@@ -1479,6 +1485,9 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
             doActivate = false;
             requestFocus = false;
         }
+	
+        if (frame->frameOptions() & YFrameWindow::foNoFocusOnMap)
+            requestFocus = false;
     }
 
     frame->setManaged(true);
@@ -2740,6 +2749,8 @@ void YWindowManager::handleRRScreenChangeNotify(const XRRScreenChangeNotifyEvent
 
     int nw = DisplayWidth(xapp->display(), DefaultScreen(xapp->display()));
     int nh = DisplayHeight(xapp->display(), DefaultScreen(xapp->display()));
+    updateXineramaInfo(nw, nh);
+
     if (width() != nw ||
         height() != nh)
     {
@@ -2748,7 +2759,6 @@ void YWindowManager::handleRRScreenChangeNotify(const XRRScreenChangeNotifyEvent
              nw,
              nh));
         setSize(nw, nh);
-        updateXineramaInfo();
         updateWorkArea();
 #ifdef CONFIG_TASKBAR
         if (taskBar) {
