@@ -76,10 +76,10 @@ static void initPixmaps() {
     YResourcePaths themedirs(paths, base, true);
     YResourcePaths subdirs(paths, base);
 
-    /* 
+    /*
      * that sucks, a neccessary workaround for differering startmenu pixmap
      * filename. This will be unified and be a forced standard in
-     * icewm-2 
+     * icewm-2
      */
     startImage = themedirs.loadImage(base, "start.xpm");
     if (startImage == null || !startImage->valid())
@@ -180,13 +180,17 @@ void EdgeTrigger::stopHide() {
         fAutoHideTimer->stopTimer();
 }
 
+extern unsigned int ignore_enternotify_hack;
 void EdgeTrigger::handleCrossing(const XCrossingEvent &crossing) {
+    if (crossing.serial != ignore_enternotify_hack && crossing.serial != ignore_enternotify_hack + 1)
+    {
     if (crossing.type == EnterNotify /* && crossing.mode != NotifyNormal */) {
         fDoShow = true;
         if (fAutoHideTimer)
             fAutoHideTimer->startTimer(autoShowDelay);
     } else if (crossing.type == LeaveNotify /* && crossing.mode != NotifyNormal */) {
     }
+    }
 }
 
 void EdgeTrigger::handleDNDEnter() {
@@ -870,12 +874,16 @@ void TaskBar::updateWMHints() {
         getFrame()->updateNetWMStrut();
 }
 
+
 void TaskBar::handleCrossing(const XCrossingEvent &crossing) {
-    if (crossing.type == EnterNotify /* && crossing.mode != NotifyNormal */) {
-        fEdgeTrigger->stopHide();
-    } else if (crossing.type == LeaveNotify /* && crossing.mode != NotifyNormal */) {
-        if (crossing.detail != NotifyInferior) {
-            fEdgeTrigger->startHide();
+    if (crossing.serial != ignore_enternotify_hack && crossing.serial != ignore_enternotify_hack + 1)
+    {
+        if (crossing.type == EnterNotify /* && crossing.mode != NotifyNormal */) {
+            fEdgeTrigger->stopHide();
+        } else if (crossing.type == LeaveNotify /* && crossing.mode != NotifyNormal */) {
+            if (crossing.detail != NotifyInferior) {
+                fEdgeTrigger->startHide();
+            }
         }
     }
 }
