@@ -27,9 +27,27 @@ class YXTray;
 #ifdef CONFIG_TASKBAR
 class TaskBar;
 
+class EdgeTrigger: public YWindow, public YTimerListener {
+public:
+    EdgeTrigger(TaskBar *owner);
+    virtual ~EdgeTrigger();
+
+    void startHide();
+    void stopHide();
+
+    virtual void handleDNDEnter();
+    virtual void handleDNDLeave();
+
+    virtual void handleCrossing(const XCrossingEvent &crossing);
+    virtual bool handleTimer(YTimer *t);
+private:
+    TaskBar *fTaskBar;
+    YTimer *fAutoHideTimer;
+    bool fDoShow;
+};
+
 class TaskBar:
     public YFrameClient,
-    public YTimerListener,
     public YActionListener,
     public YPopDownListener,
     public YXTrayNotifier
@@ -46,7 +64,9 @@ public:
     virtual void handleEndDrag(const XButtonEvent &down, const XButtonEvent &up);
 
     virtual void handleCrossing(const XCrossingEvent &crossing);
+#if false
     virtual bool handleTimer(YTimer *t);
+#endif
 
     virtual void actionPerformed(YAction *action, unsigned int modifiers);
     virtual void handlePopDown(YPopupWindow *popup);
@@ -65,8 +85,6 @@ public:
     void popupStartMenu();
     void popupWindowListMenu();
 
-    virtual void handleDNDEnter();
-    virtual void handleDNDLeave();
     void popOut();
     void showBar(bool visible);
     void handleCollapseButton();
@@ -90,6 +108,10 @@ public:
     void trayChanged();
     YXTray *netwmTray() { return fTray2; }
 
+    bool autoTimer(bool show);
+    void updateFullscreen(bool fullscreen);
+    Window edgeTriggerWindow() { return fEdgeTrigger->handle(); }
+
 private:
     TaskPane *fTasks;
 
@@ -126,10 +148,13 @@ private:
     YXTray *fTray2;
 
     bool fIsHidden;
+    bool fFullscreen;
     bool fIsCollapsed;
     bool fIsMapped;
     bool fMenuShown;
+#if false
     YTimer *fAutoHideTimer;
+#endif
 
     YMenu *taskBarMenu;
 
@@ -145,6 +170,8 @@ private:
     void initMenu();
     void initApplets();
     void updateLayout(int &size_w, int &size_h);
+
+    EdgeTrigger *fEdgeTrigger;
 };
 
 extern TaskBar *taskBar; // !!! get rid of this
