@@ -117,7 +117,7 @@ YXftFont::YXftFont(const char *name, bool use_xlfd):
         msg("xft: fallback from '%s'", name);
         XftFont *sans =
             XftFontOpen(xapp->display(), xapp->screen(),
-                        XFT_FAMILY, XftTypeString, "sans-serif",
+                        XFT_FAMILY, XftTypeString, "sans-serif,Bitstream Vera Serif",
                         XFT_PIXEL_SIZE, XftTypeInteger, 12,
                         NULL);
 
@@ -131,7 +131,7 @@ YXftFont::YXftFont(const char *name, bool use_xlfd):
             fAscent = sans->ascent;
             fDescent = sans->descent;
         } else
-            warn(_("Loading of fallback font \"%s\" failed."), "sans-serif");
+            warn(_("Loading of fallback font \"%s\" failed."), "sans-serif,Bitstream Vera Serif");
     }
 }
 
@@ -268,7 +268,7 @@ ref<YFont> getXftFontXlfd(const char *name) {
     ref<YFont> font(new YXftFont(name, true));
     if (font == null || !font->valid()) {
         msg("failed to load font '%s', trying fallback", name);
-        font.init(new YXftFont("sans-serif:size=12", false));
+        font.init(new YXftFont("sans-serif,Bitstream Vera Serif:size=12", false));
         if (font == null || !font->valid())
             msg("Could not load fallback Xft font.");
     }
@@ -279,7 +279,7 @@ ref<YFont> getXftFont(const char *name) {
     ref<YFont>font(new YXftFont(name, false));
     if (font == null || !font->valid()) {
         msg("failed to load font '%s', trying fallback", name);
-        font.init(new YXftFont("sans-serif:size=12", false));
+        font.init(new YXftFont("sans-serif,Bitstream Vera Serif:size=12", false));
         if (font == null || !font->valid())
             msg("Could not load fallback Xft font.");
     }
