@@ -152,7 +152,7 @@ YUChar *YLocale::unicodeString(const YLChar *lStr, size_t const lLen,
     char * inbuf((char *) lStr), * outbuf((char *) uStr);
     size_t inlen(lLen), outlen(4 * lLen);
 
-    if (0 > (int) iconv(instance->toUnicode, const_cast<char **>(&inbuf), &inlen, &outbuf, &outlen))
+    if (0 > (int) iconv(instance->toUnicode, &inbuf, &inlen, &outbuf, &outlen))
         warn(_("Invalid multibyte string \"%s\": %s"), lStr, strerror(errno));
 
     *((YUChar *) outbuf) = 0;
