@@ -35,7 +35,7 @@ XIV(bool, disableImlibCaches,                   true)
 #ifdef CONFIG_XFREETYPE
 XIV(bool, haveXft,                              true)
 #endif
-XSV(const char *, iconPath,                     0)
+XSV(const char *, iconPath,                     "/usr/share/icons:/usr/share/pixmaps")
 XSV(const char *, libDir,                       LIBDIR)
 XSV(const char *, configDir,                    CFGDIR)
 #define CONFIG_DEFAULT_THEME "icedesert/default.theme"
@@ -168,6 +168,6 @@ XIV(WMLook, wmLook,                             CONFIG_DEFAULT_LOOK)
 XSV(const char *, clrToolTip,                   "rgb:E0/E0/00")
 XSV(const char *, clrToolTipText,               "rgb:00/00/00")
 #endif
-XFV(const char *, toolTipFontName,              FONT(120), "sans-serif:size=12")
+XFV(const char *, toolTipFontName,              FONT(120), "sans-serif,Bitstream Vera Serif:size=12")
 
 #endif
